import { Component, OnInit, ElementRef, OnChanges} from '@angular/core';
import { ROUTES } from '../sidebar/sidebar.component';
import {Location, LocationStrategy, PathLocationStrategy} from '@angular/common';
import {Router} from '@angular/router';
import {AppChangeService} from '../../services/appchange.service';
import {AuthenticationService} from '../../services/authentication.service';
import {ModalComponent} from '../../modal/modal.component';
import { User } from '../../models/user.auth';

declare interface DECIDEApp {
  name: string;
}
export const APPS_DEFAULT: DECIDEApp[] = [
  { name: 'decide-app-1'},
  { name: 'decide-app-2'},
  { name: 'decide-app-3'}
];

@Component({
  selector: 'app-navbar',
  templateUrl: './navbar.component.html',
  styleUrls: ['./navbar.component.css']
})

export class NavbarComponent implements OnInit, OnChanges {
    //Logged user
    currentUser:User;
    //Current APP
     selectedApp = '-';
    //AppDesc
    private listApps: any[];
    private listTitles: any[];
    location: Location;
    private toggleButton: any;
    private sidebarVisible: boolean;

    constructor(location: Location,  private element: ElementRef, private router:Router, private appChangeService: AppChangeService, private authService: AuthenticationService) {
      this.location = location;
      this.sidebarVisible = false;
      //User
      this.currentUser = JSON.parse(localStorage.getItem('currentUser'));

    }

    ngOnInit(){
      this.listTitles = ROUTES.filter(listTitle => listTitle);
      
      this.listApps = APPS_DEFAULT.filter(listApp => listApp);
      
      //Select first app and publish in service
      this.selectedApp = this.listApps[0].name
      this.appChangeService.publishData(this.selectedApp)

      const navbar: HTMLElement = this.element.nativeElement;
      this.toggleButton = navbar.getElementsByClassName('navbar-toggle')[0];
    }

    sidebarOpen() {
        const toggleButton = this.toggleButton;
        const body = document.getElementsByTagName('body')[0];
        setTimeout(function(){
            toggleButton.classList.add('toggled');
        }, 500);
        body.classList.add('nav-open');

        this.sidebarVisible = true;
    };
    sidebarClose() {
        const body = document.getElementsByTagName('body')[0];
        this.toggleButton.classList.remove('toggled');
        this.sidebarVisible = false;
        body.classList.remove('nav-open');
    };
    sidebarToggle() {
        // const toggleButton = this.toggleButton;
        // const body = document.getElementsByTagName('body')[0];
        if (this.sidebarVisible === false) {
            this.sidebarOpen();
        } else {
            this.sidebarClose();
        }
    };

    getTitle(){
      var titlee = this.location.prepareExternalUrl(this.location.path());
      if(titlee.charAt(0) === '#'){
          titlee = titlee.slice( 2 );
      }
      //titlee = titlee.split('/').pop();
      //console.log(titlee);
      for(var item = 0; item < this.listTitles.length; item++){
          if(this.listTitles[item].path === titlee){
              return this.listTitles[item].title;
          }
      }
      return 'Dashboard';
    }
  
    onAppChange(newApp){
      console.log(newApp);
      this.selectedApp = newApp;
      this.appChangeService.publishData(this.selectedApp)
      //this.router.navigate(['']);
    }
  
    ngOnChanges(){}
    
    logout(){
        this.authService.logout();
        this.router.navigate(['/login']);
    }
  
  onNewAppDialog(){
    
  }
  

}
